Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2458)

Unified Diff: content/public/common/child_process_host.h

Issue 2420253002: Rename shell namespace to service_manager (Closed)
Patch Set: . Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/common/child_process_host.h
diff --git a/content/public/common/child_process_host.h b/content/public/common/child_process_host.h
index 5d043d00b319efc6e36aeb25222d301e07f3b2c4..850138d5491d0ce4420ed39cb2b508c2953b058f 100644
--- a/content/public/common/child_process_host.h
+++ b/content/public/common/child_process_host.h
@@ -21,7 +21,7 @@ namespace IPC {
class MessageFilter;
}
-namespace shell {
+namespace service_manager {
class InterfaceProvider;
}
@@ -98,9 +98,10 @@ class CONTENT_EXPORT ChildProcessHost : public IPC::Sender {
// Adds an IPC message filter. A reference will be kept to the filter.
virtual void AddFilter(IPC::MessageFilter* filter) = 0;
// Returns the shell::InterfaceProvider the process host can use to bind
// interfaces exposed to it from the child.
- virtual shell::InterfaceProvider* GetRemoteInterfaces() = 0;
+ virtual service_manager::InterfaceProvider* GetRemoteInterfaces() = 0;
#if defined(OS_POSIX)
// See IPC::Channel::TakeClientFileDescriptor.
« no previous file with comments | « content/public/common/associated_interface_provider.h ('k') | content/public/common/child_process_host_delegate.h » ('j') | no next file with comments »
@@ -98,9 +98,10 @@ class CONTENT_EXPORT ChildProcessHost : public IPC::Sender {
// Adds an IPC message filter. A reference will be kept to the filter.
virtual void AddFilter(IPC::MessageFilter* filter) = 0;
- // Returns the shell::InterfaceProvider the process host can use to bind
+ // Returns the service_manager::InterfaceProvider the process host can use to
+ // bind
// interfaces exposed to it from the child.

Powered by Google App Engine
This is Rietveld 408576698